__version__ = "0.2.2"
__author__ = 'Small Magellanic Cloud AI Ltd.'

from smallcloud.code_root import detect_code_root, code_to_zip
from smallcloud.launch import launch_task, shutdown
